import argparse as arg
import os

from .util import download_from_nas, list_file, upload

def bmcompiler_parser():
    parser = arg.ArgumentParser(description     = "handle nas with command line",
                                formatter_class = arg.ArgumentDefaultsHelpFormatter,
                                prog            = "python -m dtools")
    
    parser.add_argument("method", choices=["download", "upload", "list"], help="download or upload")
    
    # upload file argments : name, password, local_dir, nas_dir
    parser.add_argument("--name", type=str,help="username")
    parser.add_argument("--password", type=str,help="password")
    parser.add_argument("--local_dir", type=str,help="local dir")
    parser.add_argument("--nas_dir", type=str,help="nas dir. Attention : \n \
        1. if the nas_dir is not exist, it will be created automatically. \n \
        2. And usually you should set nas_dir as /home/Drive/xxxx. \n \
        3. upload mode and target name is not support now. ")
    parser.add_argument('--verbose', type=bool, default=False, help='verbose')
    return parser

if __name__ == "__main__":
    parser = bmcompiler_parser()
    a = parser.parse_args()
    

    if a.method == 'download':
        download_from_nas(a.url)
    
    if a.method == 'upload':
        upload(a.name, a.password, a.local_dir, a.nas_dir)
        
    if a.method == 'list': 
        list_file(a.name, a.password, a.nas_dir)
    


import argparse as arg
import os

# import .util as util 
from . import util

def bmcompiler_parser():
    parser = arg.ArgumentParser(description     = "handle nas with command line",
                                formatter_class = arg.ArgumentDefaultsHelpFormatter,
                                prog            = "python -m dtools")

    
    parser.add_argument("--method", type=str,help="method: upload or list", required=True, choices=['upload', 'list'])
    parser.add_argument("--local_dir", type=str,help="local dir")
    parser.add_argument("--temporary-token", type=str,help="nas dir. Attention : \n \
        1. temporary-token is a token given by Sophon official people for delivering files with time limition. \n ")
    return parser

def main():
    parser = bmcompiler_parser()
    a = parser.parse_args()
    
    if a.method == 'upload':
        util.upload_with_token(a.temporary_token, a.local_dir)
        
    if a.method == 'list': 
        util.list_file_with_token(a.temporary_token)

if __name__ == "__main__":
    parser = bmcompiler_parser()
    a = parser.parse_args()
    
    if a.method == 'upload':
        util.upload_with_token(a.temporary_token, a.local_dir)
        
    if a.method == 'list': 
        util.list_file_with_token(a.temporary_token)
    


#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

from importlib.metadata import entry_points

setup(
    name='sophontool',
    version='0.0.2',
    author='yifei.gao, wangyang.zuo',
    author_email='yifei.gao@sophgo.com, wangyang.zuo@sophon.com',
    description='tools for sophon',
    packages=['stool'],
    entry_points={ 'console_scripts': ['stool = stool.main:main'] },
    scripts=['stool/main.py'],
    install_requires=["requests","tqdm","pycrypto"]
)
# pipzwyqwerty123